==> _private_core_network-0.0.1.tar.gz: lib/network_resources/model/contact_model.dart <==
class ContactModel {
  int? id;
  int? isPro;
  int? userId;
  int? proId;
  String? uniqueId;
  int? lastContactDate;
  String? phone;
  String? firstName;
  String? lastName;
  String? infoName;
  String? thumbnail;
  String? comment;
  int? arckipel;
  String? userNickname;
  String? proDisplayname;
  String? firebaseId;

  ContactModel(
      {this.id,
      this.isPro,
      this.userId,
      this.proId,
      this.uniqueId,
      this.lastContactDate,
      this.phone,
      this.firstName,
      this.lastName,
      this.infoName,
      this.thumbnail,
      this.comment,
      this.arckipel,
      this.userNickname,
      this.proDisplayname,
      this.firebaseId});

  String getName() {
    if (arckipel != 1) return '${firstName ?? ''} ${lastName ?? ''}'.trim();
    return (isPro == 1 ? proDisplayname : userNickname) ?? '';
  }

  String getFirstChar() {
    return (getName()).isEmpty ? '#' : (getName()).split('').first;
  }

  ContactModel.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) this.id = json["id"];
    if (json["isPro"] is int) this.isPro = json["isPro"];
    if (json["userId"] is int) this.userId = json["userId"];
    if (json["proId"] is int) this.proId = json["proId"];
    if (json["uniqueId"] is String) this.uniqueId = json["uniqueId"];
    if (json["lastContactDate"] is int)
      this.lastContactDate = json["lastContactDate"];
    if (json["phone"] is String) this.phone = json["phone"];
    if (json["firstName"] is String) this.firstName = json["firstName"];
    if (json["lastName"] is String) this.lastName = json["lastName"];
    if (json["infoName"] is String) this.infoName = json["infoName"];
    if (json["thumbnail"] is String) this.thumbnail = json["thumbnail"];
    if (json["comment"] is String) this.comment = json["comment"];
    if (json["arckipel"] is int) this.arckipel = json["arckipel"];
    if (json["userNickname"] is String)
      this.userNickname = json["userNickname"];
    if (json["proDisplayname"] is String)
      this.proDisplayname = json["proDisplayname"];
    if (json["firebaseId"] is String) this.firebaseId = json["firebaseId"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["isPro"] = this.isPro;
    data["userId"] = this.userId;
    data["proId"] = this.proId;
    data["uniqueId"] = this.uniqueId;
    data["lastContactDate"] = this.lastContactDate;
    data["phone"] = this.phone;
    data["firstName"] = this.firstName;
    data["lastName"] = this.lastName;
    data["infoName"] = this.infoName;
    data["thumbnail"] = this.thumbnail;
    data["comment"] = this.comment;
    data["arckipel"] = this.arckipel;
    data["userNickname"] = this.userNickname;
    data["proDisplayname"] = this.proDisplayname;
    data["firebaseId"] = this.firebaseId;
    return data;
  }
}

==> _private_core_network-1.2.54.tar.gz: lib/network_resources/model/contact_model.dart <==
class ContactModel {
  int? id;
  int? isPro;
  int? userId;
  int? proId;
  String? uniqueId;
  int? lastContactDate;
  String? phone;
  String? firstName;
  String? lastName;
  String? infoName;
  String? thumbnail;
  String? comment;
  int? arckipel;
  String? userDisplayName;
  String? proDisplayname;
  String? firebaseId;

  ContactModel(
      {this.id,
      this.isPro,
      this.userId,
      this.proId,
      this.uniqueId,
      this.lastContactDate,
      this.phone,
      this.firstName,
      this.lastName,
      this.infoName,
      this.thumbnail,
      this.comment,
      this.arckipel,
      this.userDisplayName,
      this.proDisplayname,
      this.firebaseId});

  String getName() {
    if (arckipel != 1) return '${firstName ?? ''} ${lastName ?? ''}'.trim();
    return (isPro == 1 ? proDisplayname : userDisplayName) ?? '';
  }

  String getFirstChar() {
    return (getName()).isEmpty ? '#' : (getName()).split('').first;
  }

  ContactModel.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) this.id = json["id"];
    if (json["isPro"] is int) this.isPro = json["isPro"];
    if (json["userId"] is int) this.userId = json["userId"];
    if (json["proId"] is int) this.proId = json["proId"];
    if (json["uniqueId"] is String) this.uniqueId = json["uniqueId"];
    if (json["lastContactDate"] is int)
      this.lastContactDate = json["lastContactDate"];
    if (json["phone"] is String) this.phone = json["phone"];
    if (json["firstName"] is String) this.firstName = json["firstName"];
    if (json["lastName"] is String) this.lastName = json["lastName"];
    if (json["infoName"] is String) this.infoName = json["infoName"];
    if (json["thumbnail"] is String) this.thumbnail = json["thumbnail"];
    if (json["comment"] is String) this.comment = json["comment"];
    if (json["arckipel"] is int) this.arckipel = json["arckipel"];
    if (json["userdisplayName"] is String)
      this.userDisplayName = json["userdisplayName"];
    if (json["proDisplayname"] is String)
      this.proDisplayname = json["proDisplayname"];
    if (json["firebaseId"] is String) this.firebaseId = json["firebaseId"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["isPro"] = this.isPro;
    data["userId"] = this.userId;
    data["proId"] = this.proId;
    data["uniqueId"] = this.uniqueId;
    data["lastContactDate"] = this.lastContactDate;
    data["phone"] = this.phone;
    data["firstName"] = this.firstName;
    data["lastName"] = this.lastName;
    data["infoName"] = this.infoName;
    data["thumbnail"] = this.thumbnail;
    data["comment"] = this.comment;
    data["arckipel"] = this.arckipel;
    data["userdisplayName"] = this.userDisplayName;
    data["proDisplayname"] = this.proDisplayname;
    data["firebaseId"] = this.firebaseId;
    return data;
  }
}
